InAppCta class

A call-to-action button on an in-app message.

Constructors

InAppCta({required String id, required String label, required InAppCtaAction action, String? value})
const
InAppCta.fromJson(Map<String, dynamic> json)
factory

Properties

action InAppCtaAction
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited