inAppPlatformOverride property
Optional override for the platform value sent to the backend.
Defaults to ios/android/web based on the runtime.
Implementation
final String? inAppPlatformOverride;
Optional override for the platform value sent to the backend.
Defaults to ios/android/web based on the runtime.
final String? inAppPlatformOverride;